==> PyNDN-2.0b2-py2-none-any.whl: pyndn/__init__.py <==
# -*- Mode:python; c-file-style:"gnu"; indent-tabs-mode:nil -*- */
#
# Copyright (C) 2014 Regents of the University of California.
# Author: Derek Kulinski <takeda@takeda.tk>
# Author: Jeff Burke <jburke@ucla.edu>
# Author: Jeff Thompson <jefft0@remap.ucla.edu>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# A copy of the GNU Lesser General Public License is in the file COPYING.

from pyndn import control_parameters, data, exclude, face, forwarding_entry
from pyndn import forwarding_flags, interest, key_locator, meta_info, name
from pyndn import digest_sha256_signature, sha256_with_rsa_signature, signature
from pyndn import threadsafe_face
__all__ = ['control_parameters', 'data', 'exclude', 'face', 'forwarding_entry',
           'forwarding_flags', 'interest', 'key_locator', 'meta_info', 'name',
           'digest_sha256_signature', 'sha256_with_rsa_signature', 'signature',
           'threadsafe_face']

import sys as _sys

try:
    from pyndn.control_parameters import *
    from pyndn.data import *
    from pyndn.exclude import *
    from pyndn.face import *
    from pyndn.forwarding_entry import *
    from pyndn.forwarding_flags import *
    from pyndn.interest import *
    from pyndn.key_locator import *
    from pyndn.meta_info import *
    from pyndn.name import *
    from pyndn.digest_sha256_signature import *
    from pyndn.sha256_with_rsa_signature import *
    from pyndn.signature import *
    from pyndn.threadsafe_face import *
except ImportError:
    del _sys.modules[__name__]
    raise

==> PyNDN-2.1b1-py2-none-any.whl: pyndn/__init__.py <==
# -*- Mode:python; c-file-style:"gnu"; indent-tabs-mode:nil -*- */
#
# Copyright (C) 2014-2015 Regents of the University of California.
# Author: Derek Kulinski <takeda@takeda.tk>
# Author: Jeff Burke <jburke@ucla.edu>
# Author: Jeff Thompson <jefft0@remap.ucla.edu>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# A copy of the GNU Lesser General Public License is in the file COPYING.

from pyndn import control_parameters, data, exclude, face
from pyndn import forwarding_flags, interest, interest_filter, key_locator
from pyndn import meta_info, name, digest_sha256_signature
from pyndn import sha256_with_rsa_signature, signature
__all__ = ['control_parameters', 'data', 'exclude', 'face', 'forwarding_flags', 
           'interest', 'interest_filter', 'key_locator', 'meta_info', 'name',
           'digest_sha256_signature', 'sha256_with_rsa_signature', 'signature']

import sys as _sys

try:
    from pyndn.control_parameters import *
    from pyndn.data import *
    from pyndn.exclude import *
    from pyndn.face import *
    from pyndn.forwarding_flags import *
    from pyndn.interest import *
    from pyndn.interest_filter import *
    from pyndn.key_locator import *
    from pyndn.meta_info import *
    from pyndn.name import *
    from pyndn.digest_sha256_signature import *
    from pyndn.sha256_with_rsa_signature import *
    from pyndn.signature import *
except ImportError:
    del _sys.modules[__name__]
    raise
